pub fn ternary_op_assign_into<I: Index, T, LhsT, RhsT>(
dst: SparseColMatMut<'_, I, T>,
lhs: SparseColMatRef<'_, I, LhsT>,
rhs: SparseColMatRef<'_, I, RhsT>,
f: impl FnMut(&mut T, Option<&LhsT>, Option<&RhsT>),
)Expand description
returns the resulting matrix obtained by applying f to the elements from dst, lhs and
rhs, skipping entries that are unavailable in all of dst, lhs and rhs.
the sparsity patter of dst is unchanged.
panics
panics if lhs, rhs and dst don’t have matching dimensions.
panics if lhs or rhs contains an index that’s unavailable in dst.