pub fn binary_op<I: Index, T, LhsT, RhsT>(
lhs: SparseColMatRef<'_, I, LhsT>,
rhs: SparseColMatRef<'_, I, RhsT>,
f: impl FnMut(Option<&LhsT>, Option<&RhsT>) -> T,
) -> Result<SparseColMat<I, T>, FaerError>Expand description
returns the resulting matrix obtained by applying f to the elements from lhs and rhs,
skipping entries that are unavailable in both of lhs and rhs.
panics
panics if lhs and rhs don’t have matching dimensions.